==> tgp_1.0-1.tar.gz: tgp/demo/exp.R <==
###################################################
### chunk number 1: 
###################################################
library(tgp)
library(akima)
library(maptree)


###################################################
### chunk number 2: 
###################################################
exp2d.data <- exp2d.rand()
X <- exp2d.data$X; Z <- exp2d.data$Z
XX <- exp2d.data$XX


###################################################
### chunk number 3: 
###################################################
exp.bgp <- bgp(X=X, Z=Z, XX=XX, corr="exp") 	


###################################################
### chunk number 4: expbgp
###################################################
plot(exp.bgp, main='GP,')


###################################################
### chunk number 5: 
###################################################
exp.btgp <- btgp(X=X, Z=Z, XX=XX, corr="exp", R=3)


###################################################
### chunk number 6: btlm
###################################################
plot(exp.btgp, main='treed GP,')


###################################################
### chunk number 7: btlmtrees
###################################################
tgp.trees(exp.btgp)


###################################################
### chunk number 8: 
###################################################
exp.btgpllm <- btgpllm(X=X, Z=Z, XX=XX, corr="exp", R=3) 	


###################################################
### chunk number 9: expbtgpllm
###################################################
plot(exp.btgpllm, main='treed GP, LLM')

==> tgp_1.1-9.tar.gz: tgp/demo/exp.R <==
###################################################
### chunk number 1: 
###################################################
library(tgp)
library(maptree)
graphics.off()


###################################################
### chunk number 2: 
###################################################
exp2d.data <- exp2d.rand()
X <- exp2d.data$X; Z <- exp2d.data$Z
XX <- exp2d.data$XX


###################################################
### chunk number 3: 
###################################################
exp.bgp <- bgp(X=X, Z=Z, XX=XX, corr="exp") 	


###################################################
### chunk number 4: bgp
###################################################
plot(exp.bgp, main='GP,')


###################################################
### chunk number 5: 
###################################################
rl <- readline("press RETURN to continue: ")
dev.off()


###################################################
### chunk number 6: 
###################################################
exp.btgp <- btgp(X=X, Z=Z, XX=XX, corr="exp")


###################################################
### chunk number 7: btgp
###################################################
plot(exp.btgp, main='treed GP,')


###################################################
### chunk number 8: 
###################################################
rl <- readline("press RETURN to continue: ")
dev.off()


###################################################
### chunk number 9: btgptrees
###################################################
tgp.trees(exp.btgp)


###################################################
### chunk number 10: 
###################################################
rl <- readline("press RETURN to continue: ")
dev.off()


###################################################
### chunk number 11: 
###################################################
exp.btgpllm <- btgpllm(X=X, Z=Z, XX=XX, corr="exp", R=2) 	


###################################################
### chunk number 12: btgpllm
###################################################
plot(exp.btgpllm, main='treed GP LLM,')


###################################################
### chunk number 13: 
###################################################
rl <- readline("press RETURN to continue: ")
dev.off()


###################################################
### chunk number 14: 1dbtgpllm1
###################################################
plot(exp.btgpllm, main='treed GP LLM,', proj=c(1))


###################################################
### chunk number 15: 
###################################################
rl <- readline("press RETURN to continue: ")
dev.off()


###################################################
### chunk number 16: 1dbtgpllm2
###################################################
plot(exp.btgpllm, main='treed GP LLM,', proj=c(2))
